summaryrefslogtreecommitdiffstats
path: root/src/usr/diag/prdf/common/framework/service
diff options
context:
space:
mode:
authorBrian Horton <brianh@linux.ibm.com>2013-10-31 14:58:22 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2013-11-07 14:55:15 -0600
commit61716e5c9f9ffd3acc5169688739d223c0344a93 (patch)
treeaeba58fe4e8871a974e5b1c9f998296691285c08 /src/usr/diag/prdf/common/framework/service
parent2d6ab3cf820134bd3086139adea76f51bbdceb64 (diff)
downloadtalos-hostboot-61716e5c9f9ffd3acc5169688739d223c0344a93.tar.gz
talos-hostboot-61716e5c9f9ffd3acc5169688739d223c0344a93.zip
remove CDM FUNCTIONAL policy and GARD_Func type.
Change-Id: I9d8fa1cf8bfc155dec93c1d788c0d474647e6b37 RTC: 90176 Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/6990 Tested-by: Jenkins Server Reviewed-by: SHELDON R. BAILEY <baileysh@us.ibm.com> Reviewed-by: Zane Shelley <zshelle@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/usr/diag/prdf/common/framework/service')
-rw-r--r--src/usr/diag/prdf/common/framework/service/prdfRasServices_common.C12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/usr/diag/prdf/common/framework/service/prdfRasServices_common.C b/src/usr/diag/prdf/common/framework/service/prdfRasServices_common.C
index 984258f94..01d3c4668 100644
--- a/src/usr/diag/prdf/common/framework/service/prdfRasServices_common.C
+++ b/src/usr/diag/prdf/common/framework/service/prdfRasServices_common.C
@@ -295,7 +295,7 @@ errlHndl_t ErrDataService::GenerateSrcPfa( ATTENTION_TYPE i_attnType,
sdc = sdcBuffer;
// Add secondary signature
sdc.AddSignatureList( secSig );
- gardErrType = HWAS::GARD_Func;
+ gardErrType = HWAS::GARD_Fatal;
causeAttnPreviouslyReported = true;
}
}
@@ -313,7 +313,7 @@ errlHndl_t ErrDataService::GenerateSrcPfa( ATTENTION_TYPE i_attnType,
sdc = sdcBuffer;
// Add secondary signature
sdc.AddSignatureList( secSig );
- gardErrType = HWAS::GARD_Func;
+ gardErrType = HWAS::GARD_Fatal;
causeAttnPreviouslyReported = true;
}
}
@@ -406,7 +406,7 @@ errlHndl_t ErrDataService::GenerateSrcPfa( ATTENTION_TYPE i_attnType,
// If gardErrType was determined during UE/SUE processing for Check Stop,
// use that and not determine gardErrType from the sdc values.
- if (gardErrType != HWAS::GARD_Func)
+ if (gardErrType != HWAS::GARD_Fatal)
{
prdGardErrType = sdc.QueryGard();
switch (prdGardErrType)
@@ -419,12 +419,12 @@ errlHndl_t ErrDataService::GenerateSrcPfa( ATTENTION_TYPE i_attnType,
gardErrType = HWAS::GARD_Predictive;
break;
case GardAction::Fatal:
- gardErrType = HWAS::GARD_Func;
+ gardErrType = HWAS::GARD_Fatal;
break;
case GardAction::CheckStopOnlyGard:
if (MACHINE_CHECK == i_attnType)
{
- gardErrType = HWAS::GARD_Func;
+ gardErrType = HWAS::GARD_Fatal;
}
else
{
@@ -445,7 +445,7 @@ errlHndl_t ErrDataService::GenerateSrcPfa( ATTENTION_TYPE i_attnType,
}
else
{
// gardErrType is GARD_Func, set in UE/SUE processing for Check Stop.
// If NoGard was specified in this switched sdc, then keep the NoGard
if ( sdc.QueryGard() == GardAction::NoGard )
{
@@ -445,7 +445,7 @@ errlHndl_t ErrDataService::GenerateSrcPfa( ATTENTION_TYPE i_attnType,
else
{
- // gardErrType is GARD_Func, set in UE/SUE processing for Check Stop.
+ // gardErrType is GARD_Fatal, set in UE/SUE processing for Check Stop.
// If NoGard was specified in this switched sdc, then keep the NoGard
if ( sdc.QueryGard() == GardAction::NoGard )
OpenPOWER on IntegriCloud